@@ -23,13 +23,14 @@ from osc_lib import utils
 import six
 
 from openstackclient.i18n import _
+from openstackclient.identity import common
 
 
 LOG = logging.getLogger(__name__)
 
 
 class CreateCredential(command.ShowOne):
-    """Create new credential"""
+    _description = _("Create new credential")
 
     def get_parser(self, prog_name):
         parser = super(CreateCredential, self).get_parser(prog_name)
@@ -42,8 +43,7 @@ class CreateCredential(command.ShowOne):
             '--type',
             default="cert",
             metavar='<type>',
-            choices=['ec2', 'cert'],
-            help=_('New credential type'),
+            help=_('New credential type: cert, ec2, totp and so on'),
         )
         parser.add_argument(
             'data',
@@ -78,7 +78,7 @@ class CreateCredential(command.ShowOne):
 
 
 class DeleteCredential(command.Command):
-    """Delete credential(s)"""
+    _description = _("Delete credential(s)")
 
     def get_parser(self, prog_name):
         parser = super(DeleteCredential, self).get_parser(prog_name)
@@ -99,8 +99,8 @@ class DeleteCredential(command.Command):
             except Exception as e:
                 result += 1
                 LOG.error(_("Failed to delete credentials with "
-                          "ID '%(credential)s': %(e)s")
-                          % {'credential': i, 'e': e})
+                          "ID '%(credential)s': %(e)s"),
+                          {'credential': i, 'e': e})
 
         if result > 0:
             total = len(parsed_args.credential)
@@ -110,12 +110,41 @@ class DeleteCredential(command.Command):
 
 
 class ListCredential(command.Lister):
-    """List credentials"""
+    _description = _("List credentials")
+
+    def get_parser(self, prog_name):
+        parser = super(ListCredential, self).get_parser(prog_name)
+        parser.add_argument(
+            '--user',
+            metavar='<user>',
+            help=_('Filter credentials by <user> (name or ID)'),
+        )
+        common.add_user_domain_option_to_parser(parser)
+        parser.add_argument(
+            '--type',
+            metavar='<type>',
+            help=_('Filter credentials by type: cert, ec2, totp and so on'),
+        )
+        return parser
 
     def take_action(self, parsed_args):
+        identity_client = self.app.client_manager.identity
+
+        kwargs = {}
+        if parsed_args.user:
+            user_id = common.find_user(
+                identity_client,
+                parsed_args.user,
+                parsed_args.user_domain,
+            ).id
+            kwargs["user_id"] = user_id
+
+        if parsed_args.type:
+            kwargs["type"] = parsed_args.type
+
         columns = ('ID', 'Type', 'User ID', 'Blob', 'Project ID')
         column_headers = ('ID', 'Type', 'User ID', 'Data', 'Project ID')
-        data = self.app.client_manager.identity.credentials.list()
+        data = self.app.client_manager.identity.credentials.list(**kwargs)
         return (column_headers,
                 (utils.get_item_properties(
                     s, columns,
@@ -124,7 +153,7 @@ class ListCredential(command.Lister):
 
 
 class SetCredential(command.Command):
-    """Set credential properties"""
+    _description = _("Set credential properties")
 
     def get_parser(self, prog_name):
         parser = super(SetCredential, self).get_parser(prog_name)
@@ -142,9 +171,8 @@ class SetCredential(command.Command):
         parser.add_argument(
             '--type',
             metavar='<type>',
-            choices=['ec2', 'cert'],
             required=True,
-            help=_('New credential type'),
+            help=_('New credential type: cert, ec2, totp and so on'),
         )
         parser.add_argument(
             '--data',
@@ -180,7 +208,7 @@ class SetCredential(command.Command):
 
 
 class ShowCredential(command.ShowOne):
-    """Display credential details"""
+    _description = _("Display credential details")
 
     def get_parser(self, prog_name):
         parser = super(ShowCredential, self).get_parser(prog_name)
