@@ -13,14 +13,73 @@
 import json
 import uuid
 
-from openstackclient.tests.functional import base
+from openstackclient.tests.functional.network.v2 import common
 
 
-class NetworkTests(base.TestCase):
+class NetworkTests(common.NetworkTagTests):
     """Functional tests for network"""
 
-    def test_network_create(self):
-        """Test create options, delete"""
+    base_command = 'network'
+
+    def setUp(self):
+        super(NetworkTests, self).setUp()
+        # Nothing in this class works with Nova Network
+        if not self.haz_network:
+            self.skipTest("No Network service present")
+
+    def test_network_create_compute(self):
+        """Test Nova-net create options, delete"""
+        if self.haz_network:
+            self.skipTest("Skip Nova-net test")
+
+        # Network create with minimum options
+        name1 = uuid.uuid4().hex
+        cmd_output = json.loads(self.openstack(
+            'network create -f json ' +
+            '--subnet 1.2.3.4/28 ' +
+            name1
+        ))
+        self.addCleanup(self.openstack, 'network delete ' + name1)
+        self.assertIsNotNone(cmd_output["id"])
+
+        self.assertEqual(
+            name1,
+            cmd_output["label"],
+        )
+        self.assertEqual(
+            '1.2.3.0/28',
+            cmd_output["cidr"],
+        )
+
+        # Network create with more options
+        name2 = uuid.uuid4().hex
+        cmd_output = json.loads(self.openstack(
+            'network create -f json ' +
+            '--subnet 1.2.4.4/28 ' +
+            '--share ' +
+            name2
+        ))
+        self.addCleanup(self.openstack, 'network delete ' + name2)
+        self.assertIsNotNone(cmd_output["id"])
+
+        self.assertEqual(
+            name2,
+            cmd_output["label"],
+        )
+        self.assertEqual(
+            '1.2.4.0/28',
+            cmd_output["cidr"],
+        )
+        self.assertEqual(
+            True,
+            cmd_output["share_address"],
+        )
+
+    def test_network_create_network(self):
+        """Test Neutron create options, delete"""
+        if not self.haz_network:
+            self.skipTest("No Network service present")
+
         # Get project IDs
         cmd_output = json.loads(self.openstack('token issue -f json '))
         auth_project_id = cmd_output['project_id']
@@ -43,7 +102,7 @@ class NetworkTests(base.TestCase):
         self.assertNotEqual(admin_project_id, demo_project_id)
         self.assertEqual(admin_project_id, auth_project_id)
 
-        # network create with no options
+        # Network create with no options
         name1 = uuid.uuid4().hex
         cmd_output = json.loads(self.openstack(
             'network create -f json ' +
@@ -74,6 +133,7 @@ class NetworkTests(base.TestCase):
             cmd_output["router:external"],
         )
 
+        # Network create with options
         name2 = uuid.uuid4().hex
         cmd_output = json.loads(self.openstack(
             'network create -f json ' +
@@ -91,8 +151,40 @@ class NetworkTests(base.TestCase):
             cmd_output["description"],
         )
 
-    def test_network_delete(self):
+    def test_network_delete_compute(self):
         """Test create, delete multiple"""
+        if self.haz_network:
+            self.skipTest("Skip Nova-net test")
+
+        name1 = uuid.uuid4().hex
+        cmd_output = json.loads(self.openstack(
+            'network create -f json ' +
+            '--subnet 9.8.7.6/28 ' +
+            name1
+        ))
+        self.assertIsNotNone(cmd_output["id"])
+        self.assertEqual(
+            name1,
+            cmd_output["label"],
+        )
+
+        name2 = uuid.uuid4().hex
+        cmd_output = json.loads(self.openstack(
+            'network create -f json ' +
+            '--subnet 8.7.6.5/28 ' +
+            name2
+        ))
+        self.assertIsNotNone(cmd_output["id"])
+        self.assertEqual(
+            name2,
+            cmd_output["label"],
+        )
+
+    def test_network_delete_network(self):
+        """Test create, delete multiple"""
+        if not self.haz_network:
+            self.skipTest("No Network service present")
+
         name1 = uuid.uuid4().hex
         cmd_output = json.loads(self.openstack(
             'network create -f json ' +
@@ -117,147 +209,210 @@ class NetworkTests(base.TestCase):
             cmd_output["description"],
         )
 
-        del_output = self.openstack('network delete ' + name1 + ' ' + name2)
+        del_output = self.openstack('network delete %s %s' % (name1, name2))
         self.assertOutput('', del_output)
 
     def test_network_list(self):
         """Test create defaults, list filters, delete"""
         name1 = uuid.uuid4().hex
+        if self.haz_network:
+            network_options = '--description aaaa --no-default '
+        else:
+            network_options = '--subnet 3.4.5.6/28 '
         cmd_output = json.loads(self.openstack(
             'network create -f json ' +
-            '--description aaaa ' +
+            network_options +
             name1
         ))
-        self.addCleanup(self.openstack, 'network delete ' + name1)
+        self.addCleanup(self.openstack, 'network delete %s' % name1)
         self.assertIsNotNone(cmd_output["id"])
-        self.assertEqual(
-            'aaaa',
-            cmd_output["description"],
-        )
-        # Check the default values
-        self.assertEqual(
-            'UP',
-            cmd_output["admin_state_up"],
-        )
-        self.assertEqual(
-            False,
-            cmd_output["shared"],
-        )
-        self.assertEqual(
-            'Internal',
-            cmd_output["router:external"],
-        )
-        # NOTE(dtroyer): is_default is not present in the create output
-        #                so make sure it stays that way.
-        # NOTE(stevemar): is_default *is* present in SDK 0.9.11 and newer,
-        #                 but the value seems to always be None, regardless
-        #                 of the --default or --no-default value.
-        # self.assertEqual('x', cmd_output)
-        if ('is_default' in cmd_output):
+        if self.haz_network:
             self.assertEqual(
-                None,
+                'aaaa',
+                cmd_output["description"],
+            )
+            # Check the default values
+            self.assertEqual(
+                'UP',
+                cmd_output["admin_state_up"],
+            )
+            self.assertEqual(
+                False,
+                cmd_output["shared"],
+            )
+            self.assertEqual(
+                'Internal',
+                cmd_output["router:external"],
+            )
+            self.assertEqual(
+                False,
                 cmd_output["is_default"],
             )
-        self.assertEqual(
-            True,
-            cmd_output["port_security_enabled"],
-        )
+            self.assertEqual(
+                True,
+                cmd_output["port_security_enabled"],
+            )
+        else:
+            self.assertEqual(
+                '3.4.5.0/28',
+                cmd_output["cidr"],
+            )
 
         name2 = uuid.uuid4().hex
+        if self.haz_network:
+            network_options = '--description bbbb --disable '
+        else:
+            network_options = '--subnet 4.5.6.7/28 '
         cmd_output = json.loads(self.openstack(
-            'network create -f json ' +
-            '--description bbbb ' +
-            '--disable ' +
-            '--share ' +
-            name2
+            'network create -f json --share %s%s' %
+            (network_options, name2)
         ))
         self.addCleanup(self.openstack, 'network delete ' + name2)
         self.assertIsNotNone(cmd_output["id"])
-        self.assertEqual(
-            'bbbb',
-            cmd_output["description"],
-        )
-        self.assertEqual(
-            'DOWN',
-            cmd_output["admin_state_up"],
-        )
-        self.assertEqual(
-            True,
-            cmd_output["shared"],
-        )
-        if ('is_default' in cmd_output):
+        if self.haz_network:
             self.assertEqual(
-                None,
+                'bbbb',
+                cmd_output["description"],
+            )
+            self.assertEqual(
+                'DOWN',
+                cmd_output["admin_state_up"],
+            )
+            self.assertEqual(
+                True,
+                cmd_output["shared"],
+            )
+            self.assertEqual(
+                False,
                 cmd_output["is_default"],
             )
-        self.assertEqual(
-            True,
-            cmd_output["port_security_enabled"],
-        )
+            self.assertEqual(
+                True,
+                cmd_output["port_security_enabled"],
+            )
+        else:
+            self.assertEqual(
+                '4.5.6.0/28',
+                cmd_output["cidr"],
+            )
+            self.assertEqual(
+                True,
+                cmd_output["share_address"],
+            )
+
+        # Test list
+        cmd_output = json.loads(self.openstack(
+            "network list -f json "
+        ))
+        col_name = [x["Name"] for x in cmd_output]
+        self.assertIn(name1, col_name)
+        self.assertIn(name2, col_name)
 
         # Test list --long
-        cmd_output = json.loads(self.openstack(
-            "network list -f json " +
-            "--long"
-        ))
-        col_name = [x["Name"] for x in cmd_output]
-        self.assertIn(name1, col_name)
-        self.assertIn(name2, col_name)
+        if self.haz_network:
+            cmd_output = json.loads(self.openstack(
+                "network list -f json --long"
+            ))
+            col_name = [x["Name"] for x in cmd_output]
+            self.assertIn(name1, col_name)
+            self.assertIn(name2, col_name)
 
         # Test list --long --enable
-        cmd_output = json.loads(self.openstack(
-            "network list -f json " +
-            "--enable " +
-            "--long"
-        ))
-        col_name = [x["Name"] for x in cmd_output]
-        self.assertIn(name1, col_name)
-        self.assertNotIn(name2, col_name)
+        if self.haz_network:
+            cmd_output = json.loads(self.openstack(
+                "network list -f json --enable --long"
+            ))
+            col_name = [x["Name"] for x in cmd_output]
+            self.assertIn(name1, col_name)
+            self.assertNotIn(name2, col_name)
 
         # Test list --long --disable
-        cmd_output = json.loads(self.openstack(
-            "network list -f json " +
-            "--disable " +
-            "--long"
-        ))
-        col_name = [x["Name"] for x in cmd_output]
-        self.assertNotIn(name1, col_name)
-        self.assertIn(name2, col_name)
+        if self.haz_network:
+            cmd_output = json.loads(self.openstack(
+                "network list -f json --disable --long"
+            ))
+            col_name = [x["Name"] for x in cmd_output]
+            self.assertNotIn(name1, col_name)
+            self.assertIn(name2, col_name)
 
-        # Test list --long --share
-        cmd_output = json.loads(self.openstack(
-            "network list -f json " +
-            "--share " +
-            "--long"
-        ))
-        col_name = [x["Name"] for x in cmd_output]
-        self.assertNotIn(name1, col_name)
-        self.assertIn(name2, col_name)
+        # Test list --share
+        if self.haz_network:
+            cmd_output = json.loads(self.openstack(
+                "network list -f json --share "
+            ))
+            col_name = [x["Name"] for x in cmd_output]
+            self.assertNotIn(name1, col_name)
+            self.assertIn(name2, col_name)
 
-        # Test list --long --no-share
-        cmd_output = json.loads(self.openstack(
-            "network list -f json " +
-            "--no-share " +
-            "--long"
+        # Test list --no-share
+        if self.haz_network:
+            cmd_output = json.loads(self.openstack(
+                "network list -f json --no-share "
+            ))
+            col_name = [x["Name"] for x in cmd_output]
+            self.assertIn(name1, col_name)
+            self.assertNotIn(name2, col_name)
+
+    def test_network_dhcp_agent(self):
+        if not self.haz_network:
+            self.skipTest("No Network service present")
+
+        name1 = uuid.uuid4().hex
+        cmd_output1 = json.loads(self.openstack(
+            'network create -f json --description aaaa %s' % name1
         ))
-        col_name = [x["Name"] for x in cmd_output]
-        self.assertIn(name1, col_name)
-        self.assertNotIn(name2, col_name)
+
+        self.addCleanup(self.openstack, 'network delete %s' % name1)
+
+        # Get network ID
+        network_id = cmd_output1['id']
+
+        # Get DHCP Agent ID
+        cmd_output2 = json.loads(self.openstack(
+            'network agent list -f json --agent-type dhcp'
+        ))
+        agent_id = cmd_output2[0]['ID']
+
+        # Add Agent to Network
+        self.openstack(
+            'network agent add network --dhcp %s %s' % (agent_id, network_id)
+        )
+
+        # Test network list --agent
+        cmd_output3 = json.loads(self.openstack(
+            'network list -f json --agent %s' % agent_id
+        ))
+
+        # Cleanup
+        # Remove Agent from Network
+        self.openstack(
+            'network agent remove network --dhcp %s %s' %
+            (agent_id, network_id)
+        )
+
+        # Assert
+        col_name = [x["ID"] for x in cmd_output3]
+        self.assertIn(
+            network_id, col_name
+        )
 
     def test_network_set(self):
         """Tests create options, set, show, delete"""
+        if not self.haz_network:
+            self.skipTest("No Network service present")
+
         name = uuid.uuid4().hex
         cmd_output = json.loads(self.openstack(
-            'network create -f json ' +
-            '--description aaaa ' +
-            '--enable ' +
-            '--no-share ' +
-            '--internal ' +
-            '--no-default ' +
-            '--enable-port-security ' +
+            'network create -f json '
+            '--description aaaa '
+            '--enable '
+            '--no-share '
+            '--internal '
+            '--no-default '
+            '--enable-port-security %s' %
             name
         ))
-        self.addCleanup(self.openstack, 'network delete ' + name)
+        self.addCleanup(self.openstack, 'network delete %s' % name)
         self.assertIsNotNone(cmd_output["id"])
         self.assertEqual(
             'aaaa',
@@ -275,28 +430,23 @@ class NetworkTests(base.TestCase):
             'Internal',
             cmd_output["router:external"],
         )
-        # NOTE(dtroyer): is_default is not present in the create output
-        #                so make sure it stays that way.
-        # NOTE(stevemar): is_default *is* present in SDK 0.9.11 and newer,
-        #                 but the value seems to always be None, regardless
-        #                 of the --default or --no-default value.
-        if ('is_default' in cmd_output):
-            self.assertEqual(
-                None,
-                cmd_output["is_default"],
-            )
+
+        self.assertEqual(
+            False,
+            cmd_output["is_default"],
+        )
         self.assertEqual(
             True,
             cmd_output["port_security_enabled"],
         )
 
         raw_output = self.openstack(
-            'network set ' +
-            '--description cccc ' +
-            '--disable ' +
-            '--share ' +
-            '--external ' +
-            '--disable-port-security ' +
+            'network set '
+            '--description cccc '
+            '--disable '
+            '--share '
+            '--external '
+            '--disable-port-security %s' %
             name
         )
         self.assertOutput('', raw_output)
@@ -321,7 +471,6 @@ class NetworkTests(base.TestCase):
             'External',
             cmd_output["router:external"],
         )
-        # why not 'None' like above??
         self.assertEqual(
             False,
             cmd_output["is_default"],
@@ -330,29 +479,3 @@ class NetworkTests(base.TestCase):
             False,
             cmd_output["port_security_enabled"],
         )
-
-        # NOTE(dtroyer): There is ambiguity around is_default in that
-        #                it is not in the API docs and apparently can
-        #                not be set when the network is --external,
-        #                although the option handling code only looks at
-        #                the value of is_default when external is True.
-        raw_output = self.openstack(
-            'network set ' +
-            '--default ' +
-            name
-        )
-        self.assertOutput('', raw_output)
-
-        cmd_output = json.loads(self.openstack(
-            'network show -f json ' + name
-        ))
-
-        self.assertEqual(
-            'cccc',
-            cmd_output["description"],
-        )
-        # NOTE(dtroyer): This should be 'True'
-        self.assertEqual(
-            False,
-            cmd_output["port_security_enabled"],
-        )
